@@ -13,7 +13,7 @@ dsbase = urljoin(hubbase, "services/downloadservice/fetch/pnfs/cta.cscs.ch")
 
 
 def list_dir(url):
-    fullurl = urljoin(urljoin(dsbase, "pnfs/cta.cscs.ch/"), url)
+    fullurl = urljoin(dsbase, url)
     
     r = requests.get(
                 fullurl,
